==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACharBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ACharBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e3942c4308bfca4d soot_jimple_parser_node_ACharBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TChar$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$_init$ce58a2ab899dce8d(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TChar$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$getChar$72a27a7f92e9d2a4(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$setChar$72302f161c46f395(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$getChar$72a27a7f92e9d2a4;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$setChar$72302f161c46f395;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TChar$object	*(*getChar$72a27a7f92e9d2a4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setChar$72302f161c46f395)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods	soot_jimple_parser_node_ACharBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TChar$object	*__5fchar__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs	soot_jimple_parser_node_ACharBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ACharBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ACharBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACharBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACharBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACharBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ACharBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e3942c4308bfca4d soot_jimple_parser_node_ACharBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TChar$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$_init$ce58a2ab899dce8d(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TChar$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$getChar$72a27a7f92e9d2a4(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$setChar$72302f161c46f395(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACharBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$getChar$72a27a7f92e9d2a4;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$setChar$72302f161c46f395;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TChar$object	*(*getChar$72a27a7f92e9d2a4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setChar$72302f161c46f395)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vmethods	soot_jimple_parser_node_ACharBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TChar$object	*__5fchar__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_refs	soot_jimple_parser_node_ACharBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ACharBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ACharBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACharBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACharBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACharBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ACharBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACharBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACharBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACharBaseTypeNoName_H_ */
